
/*  -*- MaTX -*-
 *
 *  【名前】
 *      logspace() - 対数等間隔ベクトル
 *
 *  【形式】
 *      y = logspace(x1, x2, n, ...)
 *         Array y;
 *         Real x1, x2;
 *         ...
 *         Integer n = 100;
 *
 *  【機能説明】
 *      logspace(x1,x2) は，10^x1 と 10^x2 を対数等間隔で 50 分割した 50 個
 *      の値からなる行ベクトルを返す。もし，x2 が PI なら，10^x1 と PI を
 *      対数等間隔する。
 *      logspace(x1,x2,N) は，10^x1 と 10^x2 を対数等間隔で N 分割した N 個の
 *      値からなる行ベクトルを返す。
 *
 *  【関連項目】
 *      linspace
 */

Func Array logspace(x1, x2, n, ...)
	Real x1, x2;
	Integer n;
{
	Array y;

	error(nargchk(2, 3, nargs, "logspace"));

	if (nargs == 2) {
		n = 50;
	}
	if (x2 == PI) {
		x2 = log10(PI);
	}
	if (0 < x1 && 0 < x2 && (abs(x1) <= 0.1 || 10.0 <= abs(x2))) {
		x1 = log10(x1);
		x2 = log10(x2);
	}

	y = 10.0 .^ [x1 .+ [0:n-2]*(x2-x1)/(n-1), x2];
	return y;
}
