
/*  -*- MaTX -*-
 *
 *  【名前】
 *      ceil() - 正の無限大方向への丸め
 *
 *  【形式】
 *      y = ceil(x)
 *         (Real|Complex|Polynomial|Rational) y;
 *         (Real|Complex|Polynomial|Rational) x;
 *
 *      Y = ceil(X)
 *         (Matrix|Array|Index) Y;
 *         (Matrix|Array|index) X;
 *
 *  【機能説明】
 *      実数 x について，ceil(x)は，x を正の無限大方向に最も近い整数に
 *      丸める。複素数 x について，ceil(x) は，x の実部と虚部をそれぞれ
 *      正の無限大方向に最も近い整数に丸める。(多項式|有理多項式) x に
 *      について，ceil(x) は，x の各係数を正の無限大方向に最も近い整数に
 *      丸める。
 *
 *	    ceil(X)は，(行列|配列|指数) X の各成分に ceil(X(i,j)) を作用した
 *      結果からなる(行列|配列|指数) を求める。Y の大きさは X の大きさと
 *      同じになる。
 *
 *  【例題】
 *      >> y = ceil(3.14)
 *      y = 4
 *      >> y = ceil((3.14, 2.5))
 *      y = (4,3)
 *      >> s = Polynomial("s");
 *      >> y = ceil(2.1*s + 3.2)
 *      y = 3s + 4
 *      >> Y = ceil([1.2 3.4 5.6])
 *      === [Y] : (  1,  3) ===
 *                 (  1)           (  2)           (  3)     
 *      (  1)  2.00000000E+00  4.00000000E+00  6.00000000E+00
 *
 *  【関連項目】
 *      fix(), floor(), round(), round2z(),
 */
