
/*  -*- MaTX -*-
 *
 *  【名前】
 *      derivative() - 微分(導関数)
 *
 *  【形式】
 *      y = derivative(x)
 *         (Integer|Real|Complex|Polynomial|Rational) y;
 *         (Integer|Real|Complex|Polynomial|Rational) x;
 *
 *      y = derivative(x,k)
 *         (Integer|Real|Complex|Polynomial|Rational) y;
 *         (Integer|Real|Complex|Polynomial|Rational) x;
 *         Integer k;
 *
 *      Y = derivative(X)
 *         (Matrix|Array) Y;
 *         (Matrix|Array) X;
 *
 *      Y = derivative(X,k)
 *         (Matrix|Array) Y;
 *         (Matrix|Array) X;
 *         Integer k;
 *
 *  【機能説明】
 *      (整数|実数|複素数) x について，derivative(x)はゼロになる。
 *      (多項式|有理多項式) x について，derivative(x)は x の導関数を求める。
 *      derivative(x,k) は，k 階の導関数を求める。
 *
 *	    X が(行列|配列)のとき，X の各成分に derivative(X(i,j)) を作用した
 *      結果からなる(行列|配列)を求める。Y の大きさは X の大きさと同じになる。
 *      derivative(X,k) は，k 階の導関数を求める。
 *
 *  【例題】
 *      >> y = derivative(3.14)
 *      y = 0
 *      >> y = derivative((3.14, 2.6))
 *      y = (0.0, 0.0)
 *      >> s = Polynomial("s");
 *      >> y = derivative((1,3)*s + (2,4))
 *      y = (1,3)
 *      >> Y = derivative([s^2+3*s+4, 2*s+1])
 *      === [Y] : (  1,  2) ===
 *           [          (  1)           ]  [          (  2)           ]
 *      (  1)          2 s + 3                          2             
 *      >> Y = derivative([s^2+3*s+4, 2*s+1],2)
 *      === [Y] : (  1,  2) ===
 *           [          (  1)           ]  [          (  2)           ]
 *      (  1)             2                             0             
 *
 *  【関連項目】
 *      integral()
 */
