
/*  -*- MaTX -*-
 *
 *  【名前】
 *      higher() - 多項式の係数を高次へシフトする
 *
 *  【形式】
 *      y = higher(x)
 *         (Polynomial|Rational) x;
 *
 *      y = higher(x,k)
 *         (Polynomial|Rational) x;
 *         Integer k;
 *
 *      Y = higher(X)
 *         (Matrix|Array|Index) X;
 *
 *      Y = higher(X,k)
 *         (Matrix|Array|Index) X;
 *         Integer k;
 *
 *  【機能説明】
 *      higher(x)は，多項式と有理多項式(分子多項式と分母多項式)の係数を
 *      高次へ 1 個シフトする。higher(x,k)は，高次へ k 個シフトする。
 *      定数項にはゼロが代入される。
 *
 *      X が(行列|配列)のとき，成分毎に higher(X(i,j)) を作用した結果
 *      からなる(行列|配列)を求める。
 *
 *  【例題】
 *      >> s = Polynomial("s");
 *      >> y = higher(s + 1)
 *      y = s^2 + s
 *      >> X = [s + 2, 3];
 *      >> Y = higher(X, 2)
 *      === [Y] : (  1,  2) ===
 *           [          (  1)           ]  [          (  2)           ]
 *      (  1)        s^3 + 2 s^2                      3 s^2           
 * 
 *  【関連項目】
 *      lower(), derivative(), integral()
 */
