
/*  -*- MaTX -*-
 *
 *  【名前】
 *      lower() - 多項式の係数を低次へシフトする
 *
 *  【形式】
 *      y = lower(x)
 *         (Polynomial|Rational) x;
 *
 *      y = lower(x,k)
 *         (Polynomial|Rational) x;
 *         Integer k;
 *
 *      Y = lower(X)
 *         (Matrix|Array|Index) X;
 *
 *      Y = lower(X,k)
 *         (Matrix|Array|Index) X;
 *         Integer k;
 *
 *  【機能説明】
 *      lower(x)は，多項式と有理多項式(分子多項式と分母多項式)の係数を
 *      低次へ 1 個シフトする。lower(x,k)は，低次へ k 個シフトする。
 *      定数項にはゼロが代入される。
 *
 *      X が(行列|配列)のとき，成分毎に lower(X(i,j)) を作用した結果
 *      からなる(行列|配列)を求める。
 *
 *  【例題】
 *      >> s = Polynomial("s");
 *      >> y = lower(2*s + 1)
 *      y = 2
 *      >> X = [2*s^2 + 3*s + 4, 3];
 *      >> Y = lower(X, 2)
 *      === [Y] : (  1,  2) ===
 *           [          (  1)           ]  [          (  2)           ]
 *      (  1)             2                             0             
 * 
 *  【関連項目】
 *      higher(), derivative(), integral()
 */
