
/*  -*- MaTX -*-
 *
 *  【名前】
 *      pow() - 累乗
 *
 *  【形式】
 *      y = pow(x,k)
 *         (Integer|Real|Complex|Polynomial|Rational) y;
 *         (Integer|Real|Complex|Polynomial|Rational) x;
 *         Integer k;
 *
 *      Y = pow(X,k)
 *         (Matrix|Array) Y;
 *         (Matrix|Array) X;
 *         Integer k;
 *
 *      y = pow(x,p)
 *         (Integer|Real|Complex) y;
 *         (Integer|Real|Complex) x;
 *         Real p;
 *
 *      Y = pow(X,p)
 *         Array Y;
 *         Array X;
 *         Real p;
 *
 *      y = pow(x,c)
 *         Complex y;
 *         (Integer|Real|Complex) y;
 *         Complex c;
 *
 *      Y = pow(X,c)
 *         Array Y;
 *         Array X;
 *         Complex c;;
 *
 *      Y = pow(x,X)
 *         Array Y;
 *         (Integer|Real|Complex|Polynomial|Rational) x;
 *         Array X;
 *
 *      Y = pow(X,K)
 *         Array Y;
 *         Array X;
 *         Array K;
 *
 *  【機能説明】
 *      スカラー型(整数|実数|複素数|多項式|有理多項式) x について，
 *      k が整数のとき，pow(x,k)は x の k 乗 x^k を求める。
 *
 *	    (行列|配列) X について，k が整数のとき，pow(X,k)は，X^k を
 *      求める。ただし，配列の場合，成分毎に X(i,j)^k を計算する。
 *
 *      スカラー型(整数|実数|複素数) x について，p が実数のとき，
 *      pow(x,p)は x の p 乗 x^p を求める。
 *
 *	    配列 X について，p が実数のとき，pow(X,k)は，成分毎に X(i,j)^p を
 *      計算する。
 *
 *      スカラー型(整数|実数|複素数) x について，c が複素数のとき，
 *      pow(x,c)は x の c 乗 x^c を求める。
 *
 *	    配列 X について，c が複素数のとき，pow(X,c)は，成分毎に X(i,j)^c を
 *      計算する。
 *
 *      スカラー型(整数|実数|複素数|多項式|有理多項式) x について，
 *      X が配列のとき，pow(x,X)は，X の成分毎に x^X(i,j) を計算し，
 *      X と同じ大きさの配列を求める。
 *
 *	    配列 X について，K が配列のとき，pow(X,K)は，成分毎に 
 *      X(i,j)^K(i,j) を計算する。X と K の大きさは一致しなければならない。
 *
 *  【例題】
 *      >> y = pow(2,10)
 *      y = 1024
 *      >> y = pow((2,3), 3)
 *      y = (-46,9)
 *      >> s = Polynomial("s");
 *      >> y = pow(2*s + 3, 3)
 *      y = 8 s^3 + 36 s^2 + 54 s + 27
 *      >> Y = pow([[1 2][3 4]], 3)
 *      === [Y] : (  2,  2) ===
 *                 (  1)           (  2)     
 *      (  1)  3.70000000E+01  5.40000000E+01
 *      (  2)  8.10000000E+01  1.18000000E+02
 *      >> Y = pow(Array([[1 2][3 4]]), 3)
 *      === [Y] : (  2,  2) ===
 *                 (  1)           (  2)     
 *      (  1)  1.00000000E+00  8.00000000E+00
 *      (  2)  2.70000000E+01  6.40000000E+01
 *
 *  【関連項目】
 *      conj(), trans()
 */
