
/*  -*- MaTX -*-
 *
 *  【名前】
 *      rem() - 除算の余り
 *
 *  【形式】
 *      k = rem(i,j)      k = rem(i,j)    k = rem(i,j)    k = rem(i,j)
 *         Integer k;        Real k;         Real k;         Real k;
 *         Intger i, j;      Intger i;       Real i;         Real i;
 *                           Real j;         Integer j;      Real j;
 *      P = rem(X,Y)
 *         (Matrix|Array|Index) P;
 *         (Matrix|Array|Index) X,Y;
 *
 *      Y = rem(i,X)                     Y = rem(X,i)
 *         (Matrix|Array|Index) Y;          (Matrix|Array|Index) Y;
 *         Intger i;                        (Matrix|Array|Index) X;
 *         (Matrix|Array|Index) X;          Integer i;
 *
 *      Y = rem(i,X)                     Y = rem(X,i)
 *         (Matrix|Array|Index) Y;          (Matrix|Array|Index) Y;
 *         Real i;                          (Matrix|Array|Index) X;
 *         (Matrix|Array|Index) X;          Real i;
 *
 *  【機能説明】
 *      i と j が整数のとき，rem(i,j)は除算の余り i - (i/j)*j を求める。
 *      i または j が実数のとき，rem(i,j)は除算の余り i - fix(i/j)*j
 *      を求める。
 *
 *	    P = rem(X,Y)は，(行列|配列|指数) X と Y の各成分に rem(X(i,j), Y(i,j))
 *      を作用した結果からなる (行列|配列|指数) を求める。P の大きさは X の
 *      大きさと同じになる。引数の一方が行列型(行列|配列|指数)で，もう一方が
 *      が整数または実数のとき，スカラ型のデータは，その値で満たされた行列
 *      に変換され，演算が行われる。
 *
 *  【例題】
 *      >> k = rem(3,2)
 *      k = 1
 *      >> k = rem(3.14, 2)
 *      k = 1.14
 *      >> Y = rem([9 8 7], [2 3 4])
 *      === [Y] : (  1,  3) ===
 *                 (  1)           (  2)           (  3)     
 *      (  1)  1.00000000E+00  2.00000000E+00  3.00000000E+00
 *      >> Y = rem([9 8 7], 3)
 *      === [Y] : (  1,  3) ===
 *                 (  1)           (  2)           (  3)     
 *      (  1)  0.00000000E+00  2.00000000E+00  1.00000000E+00
 *
 *  【関連項目】
 *      fix()
 */
